// minecraft-module-proxy:@minecraft/server
import { system } from "@minecraft/server";
import { world } from "@minecraft/server";

// src/runtime/configs/items.ts
var config = {
  hot_lava_chicken: {
    duration: 100
  }
};

// src/runtime/utils/vec2.ts
var Vec2 = class _Vec2 {
  constructor(x, y) {
    this.x = x;
    this.y = y;
  }
  static withX(v, x) {
    return new _Vec2(x, v.y);
  }
  withX(x) {
    return new _Vec2(x, this.y);
  }
  static withY(v, y) {
    return new _Vec2(v.x, y);
  }
  withY(y) {
    return new _Vec2(this.x, y);
  }
  min(v) {
    return new _Vec2(this.x < v.x ? this.x : v.x, this.y < v.y ? this.y : v.y);
  }
  static min(v1, v22) {
    return new _Vec2(v1.x < v22.x ? v1.x : v22.x, v1.y < v22.y ? v1.y : v22.y);
  }
  max(v) {
    return new _Vec2(this.x > v.x ? this.x : v.x, this.y > v.y ? this.y : v.y);
  }
  static max(v1, v22) {
    return new _Vec2(v1.x > v22.x ? v1.x : v22.x, v1.y > v22.y ? v1.y : v22.y);
  }
  static abs(v) {
    return new _Vec2(Math.abs(v.x), Math.abs(v.y));
  }
  abs() {
    return new _Vec2(Math.abs(this.x), Math.abs(this.y));
  }
  static add(v1, v22) {
    return new _Vec2(v1.x + v22.x, v1.y + v22.y);
  }
  add(v) {
    return new _Vec2(this.x + v.x, this.y + v.y);
  }
  static subtract(v1, v22) {
    return new _Vec2(v1.x - v22.x, v1.y - v22.y);
  }
  subtract(v) {
    return new _Vec2(this.x - v.x, this.y - v.y);
  }
  static multiply(v1, v22) {
    return new _Vec2(v1.x * v22.x, v1.y * v22.y);
  }
  multiply(v) {
    return new _Vec2(this.x * v.x, this.y * v.y);
  }
  static equals(v1, v22) {
    return v1.x === v22.x && v1.y === v22.y;
  }
  equals(v) {
    return this.x === v.x && this.y === v.y;
  }
  static scale(v, scalar) {
    return new _Vec2(v.x * scalar, v.y * scalar);
  }
  scale(scalar) {
    return new _Vec2(this.x * scalar, this.y * scalar);
  }
  static normal(v) {
    const length = Math.sqrt(v.x * v.x + v.y * v.y);
    return new _Vec2(v.x / length, v.y / length);
  }
  normal() {
    const length = this.mag();
    return new _Vec2(this.x / length, this.y / length);
  }
  static mag(v) {
    return Math.sqrt(v.x * v.x + v.y * v.y);
  }
  mag() {
    return Math.sqrt(this.x * this.x + this.y * this.y);
  }
  static distance(v1, v22) {
    return _Vec2.subtract(v1, v22).mag();
  }
  distance(v) {
    return this.subtract(v).mag();
  }
  static dot(v1, v22) {
    return v1.x * v22.x + v1.y * v22.y;
  }
  dot(v) {
    return this.x * v.x + this.y * v.y;
  }
  static lerp(i1, i2, alpha) {
    return v2.wrap(i1).lerp(i2, alpha);
  }
  lerp(v, alpha) {
    return this.scale(1 - alpha).add(v2.wrap(v).scale(alpha));
  }
  static floor(v) {
    return new _Vec2(Math.floor(v.x), Math.floor(v.y));
  }
  static rotate(v, angle) {
    const x = v.x * Math.cos(angle) - v.y * Math.sin(angle);
    const y = v.x * Math.sin(angle) + v.y * Math.cos(angle);
    return new _Vec2(x, y);
  }
  rotate(angle) {
    const x = this.x * Math.cos(angle) - this.y * Math.sin(angle);
    const y = this.x * Math.sin(angle) + this.y * Math.cos(angle);
    return new _Vec2(x, y);
  }
  round() {
    return new _Vec2(Math.round(this.x), Math.round(this.y));
  }
  static round(v) {
    return new _Vec2(Math.round(v.x), Math.round(v.y));
  }
  floor() {
    return new _Vec2(Math.floor(this.x), Math.floor(this.y));
  }
  clone() {
    return new _Vec2(this.x, this.y);
  }
  toString() {
    return `Vector2<${this.x}, ${this.y}>`;
  }
  unwrap() {
    return { x: this.x, y: this.y };
  }
};
var v2 = (x, y) => {
  return new Vec2(x, y);
};
v2.wrap = (v) => new Vec2(v.x, v.y);
v2.north = v2(0, -1);
v2.south = v2(0, 1);
v2.east = v2(1, 0);
v2.west = v2(-1, 0);
v2.zero = v2(0, 0);
v2.one = v2(1, 1);

// src/runtime/utils/vec3.ts
var Vec3 = class _Vec3 {
  constructor(x, y, z) {
    this.x = x;
    this.y = y;
    this.z = z;
  }
  static withX(v, x) {
    return new _Vec3(x, v.y, v.z);
  }
  withX(x) {
    return new _Vec3(x, this.y, this.z);
  }
  static withY(v, y) {
    return new _Vec3(v.x, y, v.z);
  }
  withY(y) {
    return new _Vec3(this.x, y, this.z);
  }
  static withZ(v, z) {
    return new _Vec3(v.x, v.y, z);
  }
  withZ(z) {
    return new _Vec3(this.x, this.y, z);
  }
  min(v) {
    return new _Vec3(this.x < v.x ? this.x : v.x, this.y < v.y ? this.y : v.y, this.z < v.z ? this.z : v.z);
  }
  static min(v1, v22) {
    return new _Vec3(v1.x < v22.x ? v1.x : v22.x, v1.y < v22.y ? v1.y : v22.y, v1.z < v22.z ? v1.z : v22.z);
  }
  max(v) {
    return new _Vec3(this.x > v.x ? this.x : v.x, this.y > v.y ? this.y : v.y, this.z > v.z ? this.z : v.z);
  }
  static max(v1, v22) {
    return new _Vec3(v1.x > v22.x ? v1.x : v22.x, v1.y > v22.y ? v1.y : v22.y, v1.z > v22.z ? v1.z : v22.z);
  }
  static abs(v) {
    return new _Vec3(Math.abs(v.x), Math.abs(v.y), Math.abs(v.z));
  }
  abs() {
    return new _Vec3(Math.abs(this.x), Math.abs(this.y), Math.abs(this.z));
  }
  static add(v1, v22) {
    return new _Vec3(v1.x + v22.x, v1.y + v22.y, v1.z + v22.z);
  }
  add(v) {
    return new _Vec3(this.x + v.x, this.y + v.y, this.z + v.z);
  }
  static subtract(v1, v22) {
    return new _Vec3(v1.x - v22.x, v1.y - v22.y, v1.z - v22.z);
  }
  subtract(v) {
    return new _Vec3(this.x - v.x, this.y - v.y, this.z - v.z);
  }
  static multiply(v1, v22) {
    return new _Vec3(v1.x * v22.x, v1.y * v22.y, v1.z * v22.z);
  }
  multiply(v) {
    return new _Vec3(this.x * v.x, this.y * v.y, this.z * v.z);
  }
  static equals(v1, v22) {
    return v1.x === v22.x && v1.y === v22.y && v1.z === v22.z;
  }
  equals(v) {
    return this.x === v.x && this.y === v.y && this.z === v.z;
  }
  static scale(v, scalar) {
    return new _Vec3(v.x * scalar, v.y * scalar, v.z * scalar);
  }
  scale(scalar) {
    return new _Vec3(this.x * scalar, this.y * scalar, this.z * scalar);
  }
  static normal(v) {
    const length = Math.sqrt(v.x * v.x + v.y * v.y + v.z * v.z);
    return new _Vec3(v.x / length, v.y / length, v.z / length);
  }
  normal() {
    const length = this.mag();
    return new _Vec3(this.x / length, this.y / length, this.z / length);
  }
  static mag(v) {
    return Math.sqrt(v.x * v.x + v.y * v.y + v.z * v.z);
  }
  mag() {
    return Math.sqrt(this.x * this.x + this.y * this.y + this.z * this.z);
  }
  static distance(v1, v22) {
    return _Vec3.subtract(v1, v22).mag();
  }
  distance(v) {
    return this.subtract(v).mag();
  }
  static dot(v1, v22) {
    return v1.x * v22.x + v1.y * v22.y + v1.z * v22.z;
  }
  dot(v) {
    return this.x * v.x + this.y * v.y + this.z * v.z;
  }
  static cross(v1, v22) {
    return new _Vec3(v1.y * v22.z - v1.z * v22.y, v1.z * v22.x - v1.x * v22.z, v1.x * v22.y - v1.y * v22.x);
  }
  cross(v) {
    return new _Vec3(this.y * v.z - this.z * v.y, this.z * v.x - this.x * v.z, this.x * v.y - this.y * v.x);
  }
  static lerp(v1, v22, alpha) {
    return v3.wrap(v1).lerp(v22, alpha);
  }
  lerp(v, alpha) {
    return this.scale(1 - alpha).add(v3.wrap(v).scale(alpha));
  }
  static floor(v) {
    return new _Vec3(Math.floor(v.x), Math.floor(v.y), Math.floor(v.z));
  }
  static rotateY(v, angle) {
    const x = v.x * Math.cos(angle) - v.z * Math.sin(angle);
    const z = v.x * Math.sin(angle) + v.z * Math.cos(angle);
    return new _Vec3(x, v.y, z);
  }
  rotateY(angle) {
    const x = this.x * Math.cos(angle) - this.z * Math.sin(angle);
    const z = this.x * Math.sin(angle) + this.z * Math.cos(angle);
    return new _Vec3(x, this.y, z);
  }
  round() {
    return new _Vec3(Math.round(this.x), Math.round(this.y), Math.round(this.z));
  }
  static round(v) {
    return new _Vec3(Math.round(v.x), Math.round(v.y), Math.round(v.z));
  }
  floor() {
    return new _Vec3(Math.floor(this.x), Math.floor(this.y), Math.floor(this.z));
  }
  clone() {
    return new _Vec3(this.x, this.y, this.z);
  }
  toString() {
    return `Vector3<${this.x}, ${this.y}, ${this.z}>`;
  }
  unwrap() {
    return { x: this.x, y: this.y, z: this.z };
  }
  length() {
    return Math.sqrt(this.x * this.x + this.y * this.y + this.z * this.z);
  }
  get xy() {
    return new Vec2(this.x, this.y);
  }
  static Up() {
    return new _Vec3(0, 1, 0);
  }
  static Down() {
    return new _Vec3(0, -1, 0);
  }
  static North() {
    return new _Vec3(0, 0, -1);
  }
  static South() {
    return new _Vec3(0, 0, 1);
  }
  static East() {
    return new _Vec3(1, 0, 0);
  }
  static West() {
    return new _Vec3(-1, 0, 0);
  }
  static Zero() {
    return new _Vec3(0, 0, 0);
  }
  static One() {
    return new _Vec3(1, 1, 1);
  }
};
var v3 = (x, y, z) => {
  return new Vec3(x, y, z);
};
v3.wrap = (v) => new Vec3(v.x, v.y, v.z);
v3.up = v3(0, 1, 0);
v3.down = v3(0, -1, 0);
v3.north = v3(0, 0, -1);
v3.south = v3(0, 0, 1);
v3.east = v3(1, 0, 0);
v3.west = v3(-1, 0, 0);
v3.zero = v3(0, 0, 0);
v3.one = v3(1, 1, 1);

// src/runtime/systems/items/hot-lava-chicken.ts
var DURATION = config.hot_lava_chicken.duration;
var HotLavaChickenTick;
((HotLavaChickenTick2) => {
  let activePlayers = /* @__PURE__ */ new Map();
  let isRunning = false;
  function tick() {
    for (let id of activePlayers.keys()) {
      try {
        let ent = world.getEntity(id);
        if (!ent)
          activePlayers.delete(id);
        let timeLeft = activePlayers.get(id);
        let health = ent.getComponent("minecraft:health");
        if (!health || health.currentValue <= 0) {
          activePlayers.delete(id);
          continue;
        }
        if (timeLeft % 10 === 0) {
          ent.addEffect("saturation", 20, {
            amplifier: 4,
            showParticles: false
          });
        }
        if (timeLeft <= 0) {
          activePlayers.delete(id);
          ent.runCommandAsync(
            "playsound sound.spark_amm1.lava_chicken_cooled @s"
          );
          continue;
        }
        activePlayers.set(id, timeLeft - 1);
        ent.runCommandAsync("fill ~~-1~ ~~1~ fire replace air").catch(() => {
        });
        let dir = Vec3.withY(ent.getViewDirection(), 0).normal();
        let vel = ent.getVelocity();
        if (ent.isOnGround && vel.y <= 0)
          ent.applyKnockback(dir.x, dir.z, 1, vel.y);
        try {
          ent.dimension.spawnParticle(
            "spark_amm1:hot_lava_chicken_smoke_trail",
            ent.getHeadLocation()
          );
          ent.dimension.spawnParticle(
            "spark_amm1:hot_lava_chicken_embers",
            ent.getHeadLocation()
          );
        } catch {
        }
      } catch (e) {
        activePlayers.delete(id);
      }
    }
    if (activePlayers.size)
      system.runTimeout(tick, 1);
    else
      isRunning = false;
  }
  function add(id) {
    activePlayers.set(id, DURATION);
  }
  HotLavaChickenTick2.add = add;
  function start() {
    if (!isRunning) {
      isRunning = true;
      system.runTimeout(tick, 1);
    }
  }
  HotLavaChickenTick2.start = start;
})(HotLavaChickenTick || (HotLavaChickenTick = {}));
world.afterEvents.itemCompleteUse.subscribe((e) => {
  if (e.itemStack.typeId === `${"spark_amm1"}:steves_lava_chicken`) {
    e.source.addEffect("resistance", 200, {
      amplifier: 2,
      showParticles: false
    });
    try {
      e.source.dimension.spawnParticle(
        "spark_amm1:erupting_post_eat_smoke",
        e.source.location
      );
      e.source.dimension.spawnParticle(
        "spark_amm1:erupting_post_eat_embers",
        e.source.location
      );
    } catch {
    }
    e.source.runCommandAsync(
      "playsound sound.spark_amm1.lava_chicken_used @s"
    );
    HotLavaChickenTick.add(e.source.id);
    HotLavaChickenTick.start();
  }
});
var startChickens = 1;
var playerJoinTag = "spark_amm1.joined";
world.afterEvents.playerSpawn.subscribe((event) => {
  if (event.initialSpawn) {
    if (event.player.hasTag(playerJoinTag))
      return;
    event.player.addTag(playerJoinTag);
    event.player.runCommandAsync("gamerule sendcommandfeedback false");
    event.player.runCommandAsync(`give @s ${"spark_amm1"}:steves_lava_chicken ${startChickens}`);
    event.player.runCommandAsync("gamerule sendcommandfeedback true");
    system.runTimeout(() => {
      event.player.sendMessage({
        rawtext: [
          {
            translate: "spark.amm1.chat.is_active"
          }
        ]
      });
    }, 100);
    system.runTimeout(() => {
      event.player.sendMessage({
        rawtext: [
          { translate: "spark.amm1.chat.hot_lava_chicken_danger" }
        ]
      });
    }, 140);
  }
});
